@@ -127,6 +127,6 @@ create_CRU_stack <- function(pre = FALSE,
     )
   }
 
-  s <- create_stacks(tmn, tmx, tmp, dtr, pre, pre_cv, files)
+  s <- .create_stacks(tmn, tmx, tmp, dtr, pre, pre_cv, files)
   return(s)
 }
