@@ -862,7 +862,7 @@ test_that("Test that create_stack creates tmx if requested", {
     list.files(tempdir(), pattern = ".dat.gz$", full.names = TRUE)
 
   CRU_stack_list <-
-    create_stacks(tmn, tmx, tmp, dtr, pre, pre_cv, files)
+    .create_stacks(tmn, tmx, tmp, dtr, pre, pre_cv, files)
 
   expect_named(CRU_stack_list, c("tmx"))
   expect_equal(raster::maxValue(CRU_stack_list[[1]][[1]]), 12.9)
@@ -1227,7 +1227,7 @@ test_that("Test that create_stack creates tmn if requested", {
     list.files(tempdir(), pattern = ".dat.gz$", full.names = TRUE)
 
   CRU_stack_list <-
-    create_stacks(tmn, tmx, tmp, dtr, pre, pre_cv, files)
+    .create_stacks(tmn, tmx, tmp, dtr, pre, pre_cv, files)
 
   expect_named(CRU_stack_list, c("tmn"))
   expect_equal(raster::maxValue(CRU_stack_list[[1]][[1]]), 4.3)
